@@ -1,15 +1,17 @@
-// dedupe duplicated packages, or find them in the tree
 const ArboristWorkspaceCmd = require('../arborist-cmd.js')
 
+// dedupe duplicated packages, or find them in the tree
 class FindDupes extends ArboristWorkspaceCmd {
   static description = 'Find duplication in the package tree'
   static name = 'find-dupes'
   static params = [
-    'global-style',
+    'install-strategy',
     'legacy-bundling',
+    'global-style',
     'strict-peer-deps',
     'package-lock',
     'omit',
+    'include',
     'ignore-scripts',
     'audit',
     'bin-links',
@@ -17,9 +19,10 @@ class FindDupes extends ArboristWorkspaceCmd {
     ...super.params,
   ]
 
-  async exec (args, cb) {
+  async exec (args) {
     this.npm.config.set('dry-run', true)
     return this.npm.exec('dedupe', [])
   }
 }
+
 module.exports = FindDupes
